==> discord-emoji-convert-1.3.0.tgz: package/index.js <==

var finalWords = "";

function check(suffix){
    switch(suffix){ 
        case " ":
            var thing = "   ";
            break;
        case "!":
            var thing = " :exclamation:";
            break;
        case "?":
            var thing = " :question:";
            break;
        case "0":
            var thing = " :zero:";
            break;
        case "1":
            var thing = " :one:";
            break;
        case "2":
            var thing = " :two:";
            break;
        case "3":
            var thing = " :three:";
            break;
        case "4":
            var thing = " :four:";
            break;
        case "5":
            var thing = " :five:";
            break;
        case "6":
            var thing = " :six:";
            break;
        case "7":
            var thing = " :seven:";
            break; 
        case "8":
            var thing = " :eight:";
            break;
        case "9":
            var thing = " :nine:";
            break;
        case "+":
            var thing = " :heavy_plus_sign:";
            break;
        case "-":
            var thing = " :heavy_minus_sign:";
            break;
        case "×":   
            var thing = " :heavy_multiplication_x:";
            break;
        case "*":
            var thing = " :asterisk:";
            break;
        case "$":   
            var thing = " :heavy_dollar_sign:";
            break;
        case "÷":
            var thing = " :heavy_division_sign:";
            break;
        }
        return thing;
}

function convert(phrase, counter, bigWords, textLeft){
    if(textLeft != 0){
        if(phrase.substring(counter-1,counter).match(/[a-z]/i)) {
            character = " :regional_indicator_" + phrase.substring(counter-1,counter) + ":";
            bigWords = bigWords + character;
            convert(phrase, counter + 1, bigWords, textLeft - 1);
        } else {
            bigWords = bigWords + check(phrase.substring(counter-1,counter));
            convert(phrase, counter + 1, bigWords, textLeft - 1);
        }
    } else {
        finalWords = bigWords;
    }
}

exports.bigText = function(phrase){
    var counter = 1;
    var bigWords = "";
    var textLeft = phrase.length;
    convert(phrase, counter, bigWords, textLeft);
    return finalWords.toLowerCase();
}


// This code may feel inefficient, bulky, and horrible all at the same time. That's ok, It serves its purpose. - Jacob Snarr

==> discord-emoji-convert-1.3.1.tgz: package/index.js <==

var finalWords = "";

function check(suffix){
    switch(suffix){ 
        case " ":
            var thing = "   ";
            break;
        case "!":
            var thing = " :exclamation:";
            break;
        case "?":
            var thing = " :question:";
            break;
        case "0":
            var thing = " :zero:";
            break;
        case "1":
            var thing = " :one:";
            break;
        case "2":
            var thing = " :two:";
            break;
        case "3":
            var thing = " :three:";
            break;
        case "4":
            var thing = " :four:";
            break;
        case "5":
            var thing = " :five:";
            break;
        case "6":
            var thing = " :six:";
            break;
        case "7":
            var thing = " :seven:";
            break; 
        case "8":
            var thing = " :eight:";
            break;
        case "9":
            var thing = " :nine:";
            break;
        case "+":
            var thing = " :heavy_plus_sign:";
            break;
        case "-":
            var thing = " :heavy_minus_sign:";
            break;
        case "×":   
            var thing = " :heavy_multiplication_x:";
            break;
        case "*":
            var thing = " :asterisk:";
            break;
        case "$":   
            var thing = " :heavy_dollar_sign:";
            break;
        case "/":
            var thing = " :heavy_division_sign:"
        }
        return thing;
}

function convert(phrase, counter, bigWords, textLeft){
    if(textLeft != 0){
        if(phrase.substring(counter-1,counter).match(/[a-z]/i)) {
            character = " :regional_indicator_" + phrase.substring(counter-1,counter) + ":";
            bigWords = bigWords + character;
            convert(phrase, counter + 1, bigWords, textLeft - 1);
        } else {
            bigWords = bigWords + check(phrase.substring(counter-1,counter));
            convert(phrase, counter + 1, bigWords, textLeft - 1);
        }
    } else {
        finalWords = bigWords;
    }
}

exports.bigText = function(phrase){
    var counter = 1;
    var bigWords = "";
    var textLeft = phrase.length;
    convert(phrase, counter, bigWords, textLeft);
    return finalWords.toLowerCase();
}

// This code may feel inefficient, bulky, and horrible all at the same time. That's ok, It serves its purpose. - Jacob Snarr
